"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseChecksPBC = exports.matchingMajorVersionGSF = exports.matchingMajorVersionFUI = exports.buildGradleExists = exports.serverFolderExists = exports.clientFolderExists = exports.existsCheck = void 0;
const node_fs_1 = require("node:fs");
const utils_1 = require("./utils");
const existsCheck = (path) => ({
    name: `Checking that path exists: ${path}`,
    handler: ({ directory }) => (0, node_fs_1.existsSync)(`${directory}/${path}`),
});
exports.existsCheck = existsCheck;
exports.clientFolderExists = (0, exports.existsCheck)('client');
exports.serverFolderExists = (0, exports.existsCheck)('server');
exports.buildGradleExists = (0, exports.existsCheck)('build.gradle.kts');
exports.matchingMajorVersionFUI = {
    name: 'Matching FoundationUI major version',
    handler: ({ directory, utils: { editJSONFile }, versions }) => {
        const json = editJSONFile(`${directory}/client/package.json`);
        const fuiVersion = json.get('dependencies.@genesislcap/foundation-ui');
        if (!fuiVersion) {
            throw new Error(`'@genesislcap/foundation-ui' must exist in the target project's dependencies.`);
        }
        return (0, utils_1.checkMajorVersion)(fuiVersion, versions.prerequisites.foundationUI);
    },
};
exports.matchingMajorVersionGSF = {
    name: 'Matching GSF major version',
    handler: ({ directory, versions }) => {
        const props = (0, utils_1.loadPropertiesFile)(`${directory}/server/gradle.properties`);
        if (!props.genesisVersion) {
            throw new Error(`'genesisVersion' must exist in the target project's dependencies.`);
        }
        return (0, utils_1.checkMajorVersion)(props.genesisVersion, versions.prerequisites.gsf);
    },
};
exports.baseChecksPBC = [
    exports.clientFolderExists,
    exports.serverFolderExists,
    exports.buildGradleExists,
    exports.matchingMajorVersionFUI,
    exports.matchingMajorVersionGSF,
];
//# sourceMappingURL=checks.js.map